DagIteratorMapFuncArgs

Struct DagIteratorMapFuncArgs 

pub struct DagIteratorMapFuncArgs<'a, D: DagNode> {
    pub inner: D,
    pub index: usize,
    pub depth: usize,
    pub dependents_iter: DagDependentsIterator<'a, D>,
}
Arguments of the function which is used to map DagIterator

Fields

inner: D

Item itself

index: usize

Index of the node within the original input order

depth: usize

Longest dependency chain depth (0 if no dependencies)

dependents_iter: DagDependentsIterator<'a, D>

References to dependents items