pub struct LinkLine(/* private fields */);Expand description
A column in a linking row.
Implementations
Sourceimpl LinkLine
impl LinkLine
Sourcepub const HORIZ_PARENT: LinkLine
pub const HORIZ_PARENT: LinkLine
This cell contains a horizontal line that connects to a parent.
Sourcepub const HORIZ_ANCESTOR: LinkLine
pub const HORIZ_ANCESTOR: LinkLine
This cell contains a horizontal line that connects to an ancestor.
Sourcepub const VERT_PARENT: LinkLine
pub const VERT_PARENT: LinkLine
The descendent of this cell is connected to the parent.
Sourcepub const VERT_ANCESTOR: LinkLine
pub const VERT_ANCESTOR: LinkLine
The descendent of this cell is connected to an ancestor.
Sourcepub const LEFT_FORK_PARENT: LinkLine
pub const LEFT_FORK_PARENT: LinkLine
The parent of this cell is linked in this link row and the child is to the left.
Sourcepub const LEFT_FORK_ANCESTOR: LinkLine
pub const LEFT_FORK_ANCESTOR: LinkLine
The ancestor of this cell is linked in this link row and the child is to the left.
Sourcepub const RIGHT_FORK_PARENT: LinkLine
pub const RIGHT_FORK_PARENT: LinkLine
The parent of this cell is linked in this link row and the child is to the right.
Sourcepub const RIGHT_FORK_ANCESTOR: LinkLine
pub const RIGHT_FORK_ANCESTOR: LinkLine
The ancestor of this cell is linked in this link row and the child is to the right.
Sourcepub const LEFT_MERGE_PARENT: LinkLine
pub const LEFT_MERGE_PARENT: LinkLine
The child of this cell is linked to parents on the left.
Sourcepub const LEFT_MERGE_ANCESTOR: LinkLine
pub const LEFT_MERGE_ANCESTOR: LinkLine
The child of this cell is linked to ancestors on the left.
Sourcepub const RIGHT_MERGE_PARENT: LinkLine
pub const RIGHT_MERGE_PARENT: LinkLine
The child of this cell is linked to parents on the right.
Sourcepub const RIGHT_MERGE_ANCESTOR: LinkLine
pub const RIGHT_MERGE_ANCESTOR: LinkLine
The child of this cell is linked to ancestors on the right.
Sourcepub const CHILD: LinkLine
pub const CHILD: LinkLine
The target node of this link line is the child of this column. This disambiguates between the node that is connected in this link line, and other nodes that are also connected vertically.
pub const HORIZONTAL: LinkLine
pub const VERTICAL: LinkLine
pub const LEFT_FORK: LinkLine
pub const RIGHT_FORK: LinkLine
pub const LEFT_MERGE: LinkLine
pub const RIGHT_MERGE: LinkLine
pub const ANY_MERGE: LinkLine
pub const ANY_FORK: LinkLine
pub const ANY_FORK_OR_MERGE: LinkLine
Sourceimpl LinkLine
impl LinkLine
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<LinkLine>
pub const fn from_bits(bits: u16) -> Option<LinkLine>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> LinkLine
pub const fn from_bits_truncate(bits: u16) -> LinkLine
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> LinkLine
pub const fn from_bits_retain(bits: u16) -> LinkLine
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<LinkLine>
pub fn from_name(name: &str) -> Option<LinkLine>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: LinkLine) -> bool
pub const fn intersects(&self, other: LinkLine) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: LinkLine) -> bool
pub const fn contains(&self, other: LinkLine) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: LinkLine)
pub fn remove(&mut self, other: LinkLine)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: LinkLine)
pub fn toggle(&mut self, other: LinkLine)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: LinkLine, value: bool)
pub fn set(&mut self, other: LinkLine, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: LinkLine) -> LinkLine
pub const fn intersection(self, other: LinkLine) -> LinkLine
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: LinkLine) -> LinkLine
pub const fn union(self, other: LinkLine) -> LinkLine
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: LinkLine) -> LinkLine
pub const fn difference(self, other: LinkLine) -> LinkLine
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: LinkLine) -> LinkLine
pub const fn symmetric_difference(self, other: LinkLine) -> LinkLine
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> LinkLine
pub const fn complement(self) -> LinkLine
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl LinkLine
impl LinkLine
Sourcepub const fn iter(&self) -> Iter<LinkLine>
pub const fn iter(&self) -> Iter<LinkLine>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<LinkLine>
pub const fn iter_names(&self) -> IterNames<LinkLine>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.