MetaSet

Struct MetaSet 

pub struct MetaSet { /* private fields */ }
A set that is lazily evaluated to another set on access, with an optional fast path for “contains”.

This can be useful for various cases. Especially when “contains” and “iter” have separate fast paths. For example, merge() (merge commits) obviously has a cheap “contains” fast path by checking if a given commit has multiple parents. However, if we want to iterating through the set, segmented changelog has a fast path by iterating flat segments, instead of testing commits one by one using the “contains” check.

MetaSet is different from LazySet: MetaSet’s evaluate function can return static or lazy or meta sets. LazySet does not support a “contains” fast path (yet).

MetaSet is different from a pure filtering set (ex. only has “contains” fast path), as MetaSet supports fast path for iteration, if the underlying set supports it.

Implementations

Source

impl MetaSet

pub fn from_evaluate_hints( evaluate: Box<dyn Fn() -> BoxFuture<'static, Result<Set>> + Send + Sync + 'static>, hints: Hints, ) -> Self

Constructs MetaSet from an evaluate function that returns a Set. The evaluate function is not called immediately.

pub fn with_contains( self, contains: Box<dyn for<'a> Fn(&'a MetaSet, &'a Vertex) -> BoxFuture<'a, Result<bool>> + Send + Sync>, ) -> Self

Provides a fast path for contains. Be careful to make sure “contains” matches “evaluate”.

pub async fn evaluate(&self) -> Result<Set>

Evaluate the set. Returns a new set.

pub fn evaluated(&self) -> Option<Set>

Returns the evaluated set if it was evaluated. Returns None if the set was not evaluated.