Set

Struct Set 

pub struct Set(/* private fields */);
A Set contains an immutable list of names.

It provides order-preserving iteration and set operations, and is cheaply clonable.

Implementations

Source

impl Set

pub fn empty() -> Self

Creates an empty set.

pub fn from_static_names(names: impl IntoIterator<Item = Vertex>) -> Set

Creates from a (short) list of known names.

pub fn from_iter<I>(iter: I, hints: Hints) -> Set
where I: IntoIterator<Item = Result<Vertex>> + 'static, <I as IntoIterator>::IntoIter: Send + Sync,

Creates from a (lazy) iterator of names.

pub fn from_stream(stream: BoxVertexStream, hints: Hints) -> Set

Creates from a (lazy) stream of names with hints.

pub fn from_id_iter_idmap_dag<I>( iter: I, map: Arc<dyn IdConvert + Send + Sync>, dag: Arc<dyn DagAlgorithm + Send + Sync>, ) -> Set
where I: IntoIterator<Item = Result<Id>> + 'static, <I as IntoIterator>::IntoIter: Send + Sync,

Creates from a (lazy) iterator of Ids, an IdMap, and a Dag.

pub fn from_id_iter_dag<I>( iter: I, dag: &(impl DagAlgorithm + IdMapSnapshot), ) -> Result<Set>
where I: IntoIterator<Item = Result<Id>> + 'static, <I as IntoIterator>::IntoIter: Send + Sync,

Creates from a (lazy) iterator of Ids and a struct with snapshot abilities.

pub fn from_id_set_idmap_dag( spans: IdSet, map: Arc<dyn IdConvert + Send + Sync>, dag: Arc<dyn DagAlgorithm + Send + Sync>, ) -> Set

Creates from IdSet, [IdMap] and DagAlgorithm. Callsite must make sure spans, map, dag are using the same Id mappings. Prefer from_id_set_dag if possible.

pub fn from_id_set_idmap_dag_order( spans: IdSet, map: Arc<dyn IdConvert + Send + Sync>, dag: Arc<dyn DagAlgorithm + Send + Sync>, iteration_order: Option<BasicIterationOrder>, ) -> Set

Creates from IdSet, [IdMap], DagAlgorithm, and BasicIterationOrder. Callsite must make sure spans, map, dag are using the same Id mappings.

pub fn from_id_set_dag( spans: IdSet, dag: &(impl DagAlgorithm + IdMapSnapshot), ) -> Result<Self>

Creates from IdSet and a struct with snapshot abilities. Callsite must make sure spans, dag are using the same Id mappings.

pub fn from_id_list_dag( list: IdList, dag: &(impl DagAlgorithm + IdMapSnapshot), ) -> Result<Self>

Creates from IdList and a struct with snapshot abilities. Unlike Self::from_id_set_dag, the iteration order of list will be preserved. Callsite must make sure list, dag are using the same Id mappings.

pub fn from_evaluate_contains<C>( evaluate: impl Fn() -> Result<Set> + Send + Sync + 'static, contains: C, hints: Hints, ) -> Set
where C: for<'a> Fn(&'a MetaSet, &'a Vertex) -> Result<bool> + Send + Sync + 'static,

Creates from a function that evaluates to a Set, and a contains fast path.

pub fn from_async_evaluate_contains( evaluate: Box<dyn Fn() -> BoxFuture<'static, Result<Set>> + Send + Sync>, contains: Box<dyn for<'a> Fn(&'a MetaSet, &'a Vertex) -> BoxFuture<'a, Result<bool>> + Send + Sync>, hints: Hints, ) -> Set

Creates from an async function that evaluates to a Set, and a async contains fast path.

pub fn reverse(&self) -> Set

Reverse the iteration order of the Set.

pub fn difference(&self, other: &Set) -> Set

Calculates the subset that is only in self, not in other.

pub fn intersection(&self, other: &Set) -> Set

Calculates the intersection of two sets.

pub fn union(&self, other: &Set) -> Set

Calculates the union of two sets. Iteration order might get lost.

pub fn union_preserving_order(&self, other: &Self) -> Self

Union, but preserve the iteration order (self first, other next).

pub fn union_zip(&self, other: &Set) -> Set

Similar to union, but without showfast paths, and force a “flatten zip” order. For example [1,2,3,4].union_zip([5,6]) produces this order: [1,5,2,6,3,4].

pub fn filter( &self, filter_func: Box<dyn Fn(&Vertex) -> BoxFuture<'_, Result<bool>> + Send + Sync + 'static>, ) -> Self

Filter using the given async function. If filter_func returns true for a vertex, then the vertex will be taken, other it will be skipped.

pub async fn to_parents(&self) -> Result<Option<impl Parents>>

Convert the set to a graph containing only the vertexes in the set. This can be slow on larger sets.

pub fn dag(&self) -> Option<Arc<dyn DagAlgorithm + Send + Sync>>

Obtain the attached dag if available.

pub fn id_map(&self) -> Option<Arc<dyn IdConvert + Send + Sync>>

Obtain the attached IdMap if available.

pub async fn flatten(&self) -> Result<Set>

Convert the current set into a flat static set so it can be used in some fast paths. This is useful for some common sets like obsolete() that might be represented by a complex expression.

By flattening, the iteration order might be lost.

pub async fn flatten_id( &self, id_map: Arc<dyn IdConvert + Send + Sync>, dag: Arc<dyn DagAlgorithm + Send + Sync>, ) -> Result<Set>

Convert this set to a static id set.

By flattening, the iteration order might be lost.

pub async fn flatten_names(&self) -> Result<Set>

Convert this set to a static name set.

pub fn take(&self, n: u64) -> Set

Take the first n items.

pub fn skip(&self, n: u64) -> Set

Skip the first n items.

pub fn to_id_set_and_id_map_in_o1( &self, ) -> Option<(IdSet, Arc<dyn IdConvert + Send + Sync>)>

Converts to (IdSet, IdConvert) pair in O(1). If the underlying set cannot provide such information in O(1), return None.

Useful if the callsite wants to have random access (ex.pathhistory) and control how to resolve in batches.