pub enum UnionOrder {
FirstSecond,
Zip,
}Variants
FirstSecond
The first set is iterated first using its own order. Then the second set is iterated, with duplications skipped.
Zip
Take one item from the first set, then one item from the second set (if not exist in the first set), and repeat. Note this is slightly different from “zip” as the second set is treated as not having items duplicated with the first set.