pub struct Group(pub usize);Expand description
An integer that separates distinct groups of Ids.
This can be seen as a way to pre-allocate consecutive integers for one group to make segments less fragmented.
(Group, Id) are also topologically sorted.
Tuple Fields
0: usizeImplementations
Sourceimpl Group
impl Group
Sourcepub const MASTER: Group
pub const MASTER: Group
The “master” group. usually ancestors(master).
- Expected to have most of the commits in a repo.
- Ideally free from fragmentation. In other words,
ancestors(master)can be represented in a single Span. - Ideally has limited heads. Does not scale with too many heads.
- Vertexs (commit hashes) might be lazy.
Sourcepub const NON_MASTER: Group
pub const NON_MASTER: Group
The “non-master” group.
- Concrete vertexes not in the “master” group. For example, public release branches, local feature branches.
- Expected to have multiple heads. In other words, is fragmented.
- Expected to be sparse referred. For example, the “visible heads” will refer to a bounded subset in this group.
- Expected to be non-lazy. Code paths assume Vertexs (commit hashes) are known in this group.
Sourcepub const VIRTUAL: Group
pub const VIRTUAL: Group
The “virtual” group.
- Typically, “null” and “wdir()”.
- Should not be written to disk.
- Not lazy.
pub const ALL: [Group; 3]
pub const MAX: Group
pub const COUNT: usize
pub const BITS: u32 = 8
pub const BYTES: usize = 1