IdSet

Struct IdSet 

pub struct IdSet { /* private fields */ }
A set of integer spans.

Implementations

Source

impl IdSet

pub fn from_spans<T: Into<Span>, I: IntoIterator<Item = T>>(spans: I) -> Self

Construct a IdSet containing given spans. Overlapped or adjacent spans will be merged automatically.

pub fn from_single_span(span: Span) -> Self

Construct a IdSet that contains a single span.

pub fn from_sorted_spans<T: Into<Span>, I: IntoIterator<Item = T>>( span_iter: I, ) -> Self

Construct a IdSet containing given spans. The given spans must be already sorted (i.e. larger ids first), and do not have overlapped spans. Adjacent spans will be merged automatically.

pub fn empty() -> Self

Construct an empty IdSet.

pub fn full() -> Self

Construct a full IdSet that contains everything. Warning: The Id in this set might be unknown to an actual storage.

pub fn is_empty(&self) -> bool

Check if this IdSet contains nothing.

pub fn count(&self) -> u64

Count integers covered by this IdSet.

pub fn contains(&self, value: impl Into<Span>) -> bool

Tests if a given Id or [Span] is covered by this set.

pub fn span_contains(&self, value: impl Into<Span>) -> Option<&Span>

Find the [Span] that covers the given value.

pub fn skip(&self, n: u64) -> Self

Skip the first n items.

pub fn take(&self, n: u64) -> Self

Only take the first n items.

pub fn union(&self, rhs: &IdSet) -> IdSet

Calculates the union of two sets.

pub fn intersection(&self, rhs: &IdSet) -> IdSet

Calculates the intersection of two sets.

pub fn difference(&self, rhs: &IdSet) -> IdSet

Calculates spans that are included only by this set, not rhs.

pub fn iter_desc(&self) -> IdSetIter<&IdSet>

Iterate Ids in descending order.

pub fn iter_asc(&self) -> Rev<IdSetIter<&Self>>

Iterate Ids in ascending order.

pub fn iter_span_desc(&self) -> impl Iterator<Item = &Span>

Iterate Spans in descending order.

pub fn iter_span_asc(&self) -> impl Iterator<Item = &Span>

Iterate Spans in ascending order.

pub fn max(&self) -> Option<Id>

Get the maximum id in this set.

pub fn min(&self) -> Option<Id>

Get the minimal id in this set.

pub fn as_spans(&self) -> &VecDeque<Span>

Get a reference to the spans.

pub fn push(&mut self, span: impl Into<Span>)

Make this IdSet contain the specified span.

The current implementation works best when spans are pushed in ascending or descending order.