#[non_exhaustive]pub struct VertexOptions {
pub reserve_size: u32,
pub desired_group: Group,
}Expand description
Options attached to a vertex. Usually the vertex is a head. The head and its ancestors are going to be inserted to the graph. The options controls some details about the insertion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reserve_size: u32How many ids to reserve for this vertex. Suppose this vertex has id n,
then n+1..=n+reserve_size can only be used when inserting this vertex
and its ancestors in the same batch.
Note: if any id j in the n+1..=n+reserve_size range were already
taken, then the reserve range becomes n+1..j instead. This avoids
fragmentation.
desired_group: GroupThe desired Group for this vertex. Note a vertex’s group can be
moved down (ex. NON_MASTER to MASTER) but not moved up
(ex. MASTER to NON_MASTER).
- If the vertex does not exist, it will be inserted into the
desired_group. - If the vertex is already in a lower group than
desired_group, the vertex will stay in that lower group unchanged. - If the vertex is in a higher group than
desired_group, the implementation (ex.add_heads_and_flush) might move the vertex (and its ancestors) to a lower group, or error out.