pub trait DagStrip {
// Required method
fn strip<'life0, 'life1, 'async_trait>(
&'life0 mut self,
set: &'life1 Set,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Remove vertexes and their descendants from the DAG.
Required Methods
Sourcefn strip<'life0, 'life1, 'async_trait>(
&'life0 mut self,
set: &'life1 Set,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn strip<'life0, 'life1, 'async_trait>(
&'life0 mut self,
set: &'life1 Set,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Remove the given set and their descendants on disk.
Reload and persist changes to disk (with lock) immediately.
Errors out if pending changes in NON_MASTER were added by add_heads.
After strip, the self graph might contain new vertexes because of
the reload.