pub struct MetaSet { /* private fields */ }Expand description
A set that is lazily evaluated to another set on access, with an optional fast path for “contains”.
This can be useful for various cases. Especially when “contains” and “iter”
have separate fast paths. For example, merge() (merge commits) obviously
has a cheap “contains” fast path by checking if a given commit has
multiple parents. However, if we want to iterating through the set,
segmented changelog has a fast path by iterating flat segments, instead
of testing commits one by one using the “contains” check.
MetaSet is different from LazySet: MetaSet’s evaluate function can
return static or lazy or meta sets. LazySet does not support a “contains”
fast path (yet).
MetaSet is different from a pure filtering set (ex. only has “contains”
fast path), as MetaSet supports fast path for iteration, if the underlying
set supports it.
Implementations
Sourceimpl MetaSet
impl MetaSet
Sourcepub fn from_evaluate_hints(
evaluate: Box<dyn Fn() -> BoxFuture<'static, Result<Set>> + Send + Sync + 'static>,
hints: Hints,
) -> Self
pub fn from_evaluate_hints( evaluate: Box<dyn Fn() -> BoxFuture<'static, Result<Set>> + Send + Sync + 'static>, hints: Hints, ) -> Self
Constructs MetaSet from an evaluate function that returns a
Set. The evaluate function is not called immediately.