pub struct VerLink { /* private fields */ }Expand description
A linked list tracking a logic “version” with compatibility rules:
- Append-only changes bump the version, the new version is backwards compatible.
- Non-append-only changes create a new version that is incompatible with all other versions (in the current process).
- Clones (cheaply) preserve the version.
Supported operations:
new() -> x: Create a new version that is not comparable (compatible) with other versions.clone(x) -> y: Clonextoy.x == y.xandyare compatible.bump(x) -> y: Bumpxtoy.y > x.yis backwards-compatible withx. Note:yis not comparable (compatible) with otherbump(x).x > y:trueifxis backwards compatible withy.
The linked list can be shared in other linked lists. So they form a tree effectively. Comparing to a DAG, there is no “merge” operation. Compatibility questions become reachability questions.
Implementations